pilas.depurador.ModoDepurador

Package pilas :: Module depurador :: Class ModoDepurador |
[hide private]
[frames] | no frames]

# Class ModoDepurador

source code

    object --+
             |
            ModoDepurador

Known Subclasses:
  - ModoArea
  - , ModoFisica
  - , ModoInformacionDeSistema
  - , ModoPosicion
  - , ModoPuntosDeControl
  - , ModoRadiosDeColision
  - , ModoWidgetLog

Instance Methods | [hide private]
__init__(self, depurador) x.__init__(...) initializes x; see help(type(x)) for signature | source code
comienza_dibujado(self, motor, painter, lienzo) | source code
dibuja_al_actor(self, motor, painter, lienzo, actor) | source code
termina_dibujado(self, motor, painter, lienzo) | source code
orden_de_tecla(self) | source code
sale_del_modo(self) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| tecla = ``'``F00``'``

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, depurador) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)